@@ -117,7 +117,7 @@ enum WHICHCOMMAND_RETURN_VALUES {
 	OER_WHICHCOMMAND_KICK,
 	OER_WHICHCOMMAND_INVITE,
 	OER_WHICHCOMMAND_MODE,
-	OER_WHICHCOMMAND_MASSM,
+	OER_WHICHCOMMAND_MASSMESSAGE,
 	OER_WHICHCOMMAND_HELP,
 	OER_WHICHCOMMAND_SAVE,
 	OER_WHICHCOMMAND_LIST,
@@ -278,7 +278,7 @@ enum OER_DEBUG_LEVELS {
 #define OER_HELP "For a complete command reference go to http://oer.equnet.org/help.html"
 #define DEFAULT_NICKBK_MESSAGE "prohibited nick"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
-#define OER_COPYRIGHT1 "oer version 1.0-24, Copyright (C) 2000 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer version 1.0-25, Copyright (C) 2000 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
