@@ -811,6 +811,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 	}
 	switch((which = whichcommand(command, wordcount(restptr)))) {
 	case OER_WHICHCOMMAND_TOPIC_SET:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->TOPIC_SET\n");
 		if(!isatleastopnow(channel, nick, host)) {
 			return;
 		}
@@ -823,6 +824,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_TOPIC_ADD:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->TOPIC_ADD\n");
 		if(!isatleastopnow(channel, nick, host)) {
 			return;
 		}
@@ -834,6 +836,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_TOPIC_DEL:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->TOPIC_DEL\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -848,6 +851,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_TOPIC_EDIT:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->TOPIC_EDIT\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -863,6 +867,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_TOPIC_INS:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->TOPIC_INS\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -878,12 +883,14 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_TOPIC_LIST:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->TOPIC_LIST\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
 		listtopic((tochan) ? channel : nick, tochan, channel);
 		return;
 	case OER_WHICHCOMMAND_TOPIC_GET:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->TOPIC_GET\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -892,6 +899,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		addnewtimed(mystate->now, OER_TIMED_IRC_COMMAND, OER_TIMED_IRC_COMMAND_DUMMY, outstring, NULL, NULL, NULL);
 		return;
 	case OER_WHICHCOMMAND_TOPIC_REFRESH:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->TOPIC_REFRESH\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -900,6 +908,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_TOPIC_SWAP:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->TOPIC_SWAP\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -918,6 +927,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_LOCK:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->LOCK\n");
 		proceed = 0;
 		if(isadmin(channel, host)) {
 			proceed = 1;
@@ -940,6 +950,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_UNLOCK:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->UNLOCK\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -949,6 +960,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		unlockchan(channel, nick, host);
 		return;
 	case OER_WHICHCOMMAND_RANDOM_KICK:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->RANDOM_KICK\n");
 		proceed = 0;
 		if(isadmin(channel, host)) {
 			proceed = 1;
@@ -969,6 +981,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_SYNC:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->SYNC\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -981,6 +994,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		syncnickbks(channel);
 		return;
 	case OER_WHICHCOMMAND_SYNCALL:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->SYNCALL\n");
 		if(!isopa(host)) {
 			return;
 		}
@@ -995,6 +1009,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_JUMP:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->JUMP\n");
 		if(!isopa(host)) {
 			return;
 		}
@@ -1007,6 +1022,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		mystate->reconnect = OER_RECONNECT_ADMIN;
 		return;
 	case OER_WHICHCOMMAND_QUIT:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->QUIT\n");
 		if(!isopa(host)) {
 			return;
 		}
@@ -1018,6 +1034,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		quit();
 		return;
 	case OER_WHICHCOMMAND_OP:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->OP\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1048,6 +1065,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_DOP:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->DOP\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1075,6 +1093,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_VOICE:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->VOICE\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1102,6 +1121,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_BAN:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->BAN\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1123,6 +1143,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_UNBAN:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->UNBAN\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1144,6 +1165,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_BANKICK:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->BANKICK\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1161,6 +1183,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		bankickuser(channel, p1, (strlen(restptr + ppos) > 0) ? restptr + ppos : NULL);
 		return;
 	case OER_WHICHCOMMAND_KICK:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->KICK\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1178,6 +1201,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		kickuser(channel, p1, (strlen(restptr + ppos) > 0) ? restptr + ppos : NULL);
 		return;
 	case OER_WHICHCOMMAND_INVITE:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->INVITE\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1191,7 +1215,8 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		snprintf(outstring, WRITE_BUFFER_LENGTH, "INVITE %s %s\n", nick, channel);
 		addnewtimed(mystate->now, OER_TIMED_IRC_COMMAND, OER_TIMED_IRC_COMMAND_DUMMY, outstring, NULL, NULL, NULL);
 		return;
-	case OER_WHICHCOMMAND_MASSM:
+	case OER_WHICHCOMMAND_MASSMESSAGE:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->MASSMESSAGE\n");
 		if(!isopa(host)) {
 			return;
 		}
@@ -1200,6 +1225,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_MODE:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->MODE\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1233,6 +1259,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_HELP:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->HELP\n");
 		proceed = 0;
 		for(this = mystate->channels; this != NULL && !proceed; this = this->next) {
 			if(isatleastopnow(this->name, nick, host)) {
@@ -1246,15 +1273,23 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		sendreply((tochan) ? channel : nick, tochan, 0, 0, outstring);
 		return;
 	case OER_WHICHCOMMAND_LIST:
-                if(!isatleastopnow(channel, nick, host)) {
-                        return;
-                }
-		if(!strlen(restptr)) {
+		oer_debug(OER_DEBUG_INFO, "parsecommand->LIST\n");
+		/* we are satisfied if the user is atleastopnow() on one of
+		   our channels. commands requiring channel specific authorization
+		   are checked in listcommand() */
+		proceed = 0;
+		for(this = mystate->channels; this != NULL && !proceed; this = this->next) {
+			if(isatleastopnow(this->name, nick, host)) {
+				proceed = 1;
+			}
+		}
+		if(!proceed) {
 			return;
 		}
 		listcommand((tochan) ? channel : nick, tochan, channel, nick, host, restptr);
 		return;
 	case OER_WHICHCOMMAND_LOGOFF:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->LOGOFF\n");
 		proceed = 0;
 		if(isopa(host)) {
 			proceed = 1;
@@ -1270,6 +1305,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_LOGON:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->LOGON\n");
 		proceed = 0;
 		if(isopa(host)) {
 			proceed = 1;
@@ -1285,6 +1321,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_ADD:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->ADD\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1293,6 +1330,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_DEL:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->DEL\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1301,6 +1339,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_EDIT:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->EDIT\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1309,19 +1348,34 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_SAVE:
-                if(!isatleastopnow(channel, nick, host)) {
-                        return;
-                }
+		oer_debug(OER_DEBUG_INFO, "parsecommand->SAVE\n");
+		proceed = 0;
+		for(this = mystate->channels; this != NULL && !proceed; this = this->next) {
+			if(isatleastopnow(this->name, nick, host)) {
+				proceed = 1;
+			}
+		}
+		if(!proceed) {
+			return;
+		}
 		saveall();
 		mystate->last_saved = mystate->now;
 		return;
 	case OER_WHICHCOMMAND_FLUSH:
-                if(!isatleastopnow(channel, nick, host)) {
-                        return;
-                }
+		oer_debug(OER_DEBUG_INFO, "parsecommand->FLUSH\n");
+		proceed = 0;
+		for(this = mystate->channels; this != NULL && !proceed; this = this->next) {
+			if(isatleastopnow(this->name, nick, host)) {
+				proceed = 1;
+			}
+		}
+		if(!proceed) {
+			return;
+		}
 		flushall();
 		return;
 	case OER_WHICHCOMMAND_INFO:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->INFO\n");
 		proceed = 0;
 		for(this = mystate->channels; this != NULL && !proceed; this = this->next) {
 			if(isatleastopnow(this->name, nick, host)) {
@@ -1335,6 +1389,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		sendreply((tochan) ? channel : nick, tochan, 0, 1, outstring);
 		return;
 	case OER_WHICHCOMMAND_UPTIME:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->UPTIME\n");
 		proceed = 0;
 		for(this = mystate->channels; this != NULL && !proceed; this = this->next) {
 			if(isatleastopnow(this->name, nick, host)) {
@@ -1354,6 +1409,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		sendreply((tochan) ? channel : nick, tochan, 0, 1, outstring);
 		return;
 	case OER_WHICHCOMMAND_ACTION:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->ACTION\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1363,6 +1419,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_SAY:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->SAY\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1371,6 +1428,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_RAW:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->RAW\n");
 		if(!isopa(host)) {
 			return;
 		}
@@ -1380,12 +1438,14 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_LAST:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->LAST\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
 		showlast((tochan) ? channel : nick, tochan, channel, (strlen(restptr) > 0) ? restptr : NULL);
 		return;
 	case OER_WHICHCOMMAND_QUOTE:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->QUOTE\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1402,12 +1462,14 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		}
 		return;
 	case OER_WHICHCOMMAND_SEEN:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->SEEN\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
 		showseen((tochan) ? channel : nick, tochan, channel, (strlen(restptr) > 0) ? restptr : NULL);
 		return;
 	case OER_WHICHCOMMAND_NSTATS:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->NSTATS\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
@@ -1417,6 +1479,7 @@ void parsecommand(char *target, char *nick, char *host, char *commandline)
 		nstats((tochan) ? channel : nick, tochan, channel, restptr);
 		return;
 	case OER_WHICHCOMMAND_WALL:
+		oer_debug(OER_DEBUG_INFO, "parsecommand->WALL\n");
                 if(!isatleastopnow(channel, nick, host)) {
                         return;
                 }
